@@ -266,7 +266,7 @@ class Session(object):
         ----------
         dataset : {'cpi_measures', 'fiscal', 'labor', 'real_wages', \
                 'net_trade', 'tot', 'net_public_debt', 'commodity_index', \
-                'rxr_custom', 'core_industrial'}
+                'rxr_custom', 'core_industrial', 'bonds'}
             Type of data to download.
         update : bool, default True
             Whether to update an existing dataset.
@@ -303,6 +303,7 @@ class Session(object):
 
         if dataset == "cpi_measures" or dataset == "price_measures":
             output = custom.cpi_measures(update_loc=update_loc,
+                                         revise_rows=self.revise_rows,
                                          save_loc=save_loc,
                                          only_get=self.only_get,
                                          **kwargs)
@@ -351,6 +352,12 @@ class Session(object):
                                          save_loc=save_loc,
                                          only_get=self.only_get,
                                          **kwargs)
+        elif dataset == "bonds":
+            output = custom.bonds(update_loc=update_loc,
+                                  revise_rows=self.revise_rows,
+                                  save_loc=save_loc,
+                                  only_get=self.only_get,
+                                  **kwargs)
         else:
             raise ValueError("Invalid keyword for 'dataset' parameter.")
 
